@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-12-09'; # DATE
-our $VERSION = '1.61'; # VERSION
+our $DATE = '2016-01-14'; # DATE
+our $VERSION = '1.62'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -526,37 +526,35 @@ sub hook_display_result {
     my ($self, $r) = @_;
 
     my $res  = $r->{res};
-    my $fres = $r->{fres};
     my $resmeta = $res->[3] // {};
 
     my $handle = $r->{output_handle};
 
-    # determine whether to binmode(STDOUT,":utf8")
-    my $utf8;
-    {
-        last if defined($utf8 = $ENV{UTF8});
-        if ($resmeta->{'x.hint.result_binary'}) {
-            # XXX only when format is text?
-            $utf8 = 0; last;
-        }
-        my $am = $self->action_metadata->{$r->{action}}
-            if $r->{action};
-        last if defined($utf8 //= $am->{use_utf8});
-
-        if ($r->{subcommand_data}) {
-            last if defined($utf8 //= $r->{subcommand_data}{use_utf8});
-        }
-
-        $utf8 //= $self->use_utf8
-            if $self->can("use_utf8");
-    }
-    binmode(STDOUT, ":utf8") if $utf8;
-
     if ($ENV{COMP_LINE} || $res->[3]{"cmdline.skip_format"}) {
         print $handle $res->[2];
         return;
     }
 
+    # set utf8 flag
+    my $utf8;
+    {
+        if ($resmeta->{'x.hint.result_binary'}) {
+            # XXX only when format is text?
+            $utf8 = 0; last;
+        }
+
+        my $am = $self->action_metadata->{$r->{action}}
+            if $r->{action};
+        last if defined($utf8 = $am->{use_utf8});
+
+        if ($r->{subcommand_data}) {
+            last if defined($utf8 = $r->{subcommand_data}{use_utf8});
+        }
+
+        $utf8 = $self->use_utf8;
+    }
+    binmode($handle, ":utf8") if $utf8;
+
     $self->display_result($r);
 }
 
@@ -785,7 +783,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.61 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-12-09.
+This document describes version 1.62 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2016-01-14.
 
 =head1 SYNOPSIS
 
@@ -1051,7 +1049,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
